.. currentmodule:: xpublish

#############
API reference
#############

This is a reference API class listing, and modules.

Accessor Objects
================

.. autosummary::
   :toctree: generated/

   RestAccessor
